#!/usr/bin/env node
"use strict";
/* eslint-disable no-console */
/* eslint-disable node/shebang */
/* eslint-disable require-atomic-updates */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Logger_1 = require("../Logger");
const jiti_1 = __importDefault(require("jiti"));
const node_fs_1 = require("node:fs");
const node_path_1 = __importDefault(require("node:path"));
const helpers_1 = require("yargs/helpers");
const yargs_1 = __importDefault(require("yargs/yargs"));
const log = Logger_1.Logger.child({
    namespace: 'turbowatch',
});
const findTurbowatchScript = (inputPath) => {
    let resolvedPath = null;
    const providedPath = node_path_1.default.resolve(process.cwd(), inputPath);
    const possiblePaths = [providedPath];
    if (node_path_1.default.extname(providedPath) === '') {
        possiblePaths.push(providedPath + '.ts', providedPath + '.js');
    }
    for (const possiblePath of possiblePaths) {
        if ((0, node_fs_1.existsSync)(possiblePath)) {
            resolvedPath = possiblePath;
        }
    }
    return resolvedPath;
};
const main = async () => {
    const { watch } = (0, jiti_1.default)(__filename)('../watch');
    const argv = await (0, yargs_1.default)((0, helpers_1.hideBin)(process.argv))
        .command('$0 [scripts...]', 'Start Turbowatch', (commandYargs) => {
        commandYargs.positional('scripts', {
            array: true,
            default: ['turbowatch.ts'],
            describe: 'Script with Turbowatch instructions.',
            type: 'string',
        });
    })
        .parse();
    const scriptPaths = argv.scripts;
    const resolvedScriptPaths = [];
    for (const scriptPath of scriptPaths) {
        const resolvedPath = findTurbowatchScript(scriptPath);
        if (!resolvedPath) {
            console.error('%s not found', scriptPath);
            process.exitCode = 1;
            return;
        }
        resolvedScriptPaths.push(resolvedPath);
    }
    for (const resolvedPath of resolvedScriptPaths) {
        const turbowatchConfiguration = (0, jiti_1.default)(__filename)(resolvedPath)
            .default;
        if (typeof (turbowatchConfiguration === null || turbowatchConfiguration === void 0 ? void 0 : turbowatchConfiguration.Watcher) !== 'function') {
            console.error('Expected user script to export an instance of TurbowatchController');
            process.exitCode = 1;
            return;
        }
        const turbowatchController = await watch({
            cwd: node_path_1.default.dirname(resolvedPath),
            ...turbowatchConfiguration,
        });
        process.once('SIGINT', () => {
            log.warn('received SIGINT; gracefully terminating');
            void turbowatchController.shutdown();
        });
    }
};
void main();
//# sourceMappingURL=turbowatch.js.map